@@ -25,38 +25,34 @@ class UpdateConnectionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateConnection')
 		self.set_method('PUT')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_EnvType(self):
-		return self.get_query_params().get('EnvType')
-
-	def set_EnvType(self,EnvType):
-		self.add_query_param('EnvType',EnvType)
-
-	def get_Description(self):
+	def get_Description(self): # String
 		return self.get_query_params().get('Description')
 
-	def set_Description(self,Description):
-		self.add_query_param('Description',Description)
-
-	def get_ConnectionId(self):
-		return self.get_query_params().get('ConnectionId')
-
-	def set_ConnectionId(self,ConnectionId):
-		self.add_query_param('ConnectionId',ConnectionId)
-
-	def get_Content(self):
+	def set_Description(self, Description):  # String
+		self.add_query_param('Description', Description)
+	def get_Content(self): # String
 		return self.get_query_params().get('Content')
 
-	def set_Content(self,Content):
-		self.add_query_param('Content',Content)
+	def set_Content(self, Content):  # String
+		self.add_query_param('Content', Content)
+	def get_EnvType(self): # Integer
+		return self.get_query_params().get('EnvType')
 
-	def get_Status(self):
+	def set_EnvType(self, EnvType):  # Integer
+		self.add_query_param('EnvType', EnvType)
+	def get_ConnectionId(self): # Long
+		return self.get_query_params().get('ConnectionId')
+
+	def set_ConnectionId(self, ConnectionId):  # Long
+		self.add_query_param('ConnectionId', ConnectionId)
+	def get_Status(self): # String
 		return self.get_query_params().get('Status')
 
-	def set_Status(self,Status):
-		self.add_query_param('Status',Status)
\ No newline at end of file
+	def set_Status(self, Status):  # String
+		self.add_query_param('Status', Status)
